"use client";
import React, { useEffect, useMemo, useState } from "react";
// Chakra imports
import {
  Box,
  Button,
  Flex,
  FormControl,
  Heading,
  Text,
  useColorModeValue,
} from "@chakra-ui/react";

// Custom components
import DefaultAuthLayout from "@/layouts/auth/Default";
import Form from "@/components/form/Form";

// Assets
import Link from "next/link";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { InputWrapper, PasswordWrapper } from "@/components/fields/Fields";
import { useRouter } from "next/navigation";
import { ForgotPassword } from "@/app/lib/actions/auth.actions";
import useShowToast from "@/app/hooks/useShowToast";

const formFields: FormObject[] = [
  {
    name: "email",
    label: "Email",
    type: "email",
    placeholder: "johndoe@business.com",
    required: true,
  },
];

export default function ForgotPage() {
  // Chakra color mode
  const textColor = useColorModeValue("navy.700.700", "white");
  const textColorSecondary = "gray.400";
  const textColorDetails = useColorModeValue("navy.700", "secondaryGray.600");
  const textColorBrand = useColorModeValue("brand.500", "white");
  
  // sign in logic
  const showToast = useShowToast();
  const [loginForm, setLoginForm] = useState({});
  const [formInitiated, setFormInitiated] = useState(false);
  const [formValidationSchema, setFormValidationSchema] = useState({});
  const [loading, setLoading] = useState(false);
  const formDetails = useMemo(() => prepareValidationSchema(formFields), []);
  // Destructure formDetails
  const { initialFormData, validationSchema } = formDetails;
  const router = useRouter();

  useEffect(() => {
    if (!formInitiated) {
      setLoginForm(initialFormData);
      setFormValidationSchema(validationSchema);
      setFormInitiated(true);
    }
  }, [initialFormData, validationSchema]);

  const handleSubmit = async (values: { email: string }) => {
    setLoading(true);
    try {
      const response = await ForgotPassword({ email: values.email });
      localStorage.setItem('reset_token', response.token);
      showToast("OTP sent", "Please check your email!", "success");
      router.push('/auth/otp');
    } catch (error: any) {
      showToast("Forgot failed!", error.message, "error");
    }
    finally{
    setLoading(false);
    }
  };

  const signInText = "Enter your email and to reset your password";
  return (
    <DefaultAuthLayout illustrationBackground={"/img/auth/medianet_logo.png"}>
      <Flex
        maxW={{ base: "100%", md: "max-content" }}
        w="100%"
        mx={{ base: "auto", lg: "0px" }}
        me="auto"
        h="100%"
        alignItems="start"
        justifyContent="center"
        mb={{ base: "30px", md: "30px" }}
        px={{ base: "25px", md: "0px" }}
        mt={{ base: "40px", md: "4vh" }}
        flexDirection="column"
      >
        <Box me="auto">
          <Heading color={textColor} fontSize="36px" mb="10px">
            Forgot Password
          </Heading>
          <Text
            mb="36px"
            ms="4px"
            color={textColorSecondary}
            fontWeight="400"
            fontSize="md"
          >
            {signInText}
          </Text>
        </Box>
        <Flex
          zIndex="2"
          direction="column"
          w={{ base: "100%", md: "420px" }}
          maxW="100%"
          background="transparent"
          borderRadius="15px"
          mx={{ base: "auto", lg: "unset" }}
          me="auto"
          mb={{ base: "20px", md: "auto" }}
        >
          <Form
            validationSchema={formValidationSchema}
            initialValues={loginForm}
            submitForm={(formValues, formData) => {
              handleSubmit(formValues);
            }}
          >
            <FormControl w="full">
              {formFields.map((field) =>
                field.type === "password" ? (
                  <PasswordWrapper
                    key={field.name}
                    label={field.label}
                    form={true}
                    fieldName={field.name}
                    id={field.name}
                    placeholder={field.placeholder}
                    variant="auth"
                    w="full"
                    mb="2px"
                    fontSize="sm"
                    ms={{ base: "0px", md: "0px" }}
                    fontWeight="500"
                    size="lg"
                  />
                ) : (
                  <InputWrapper
                    key={field.name}
                    form={true}
                    fieldName={field.name}
                    id={field.name}
                    placeholder={field.placeholder}
                    variant="auth"
                    w="full"
                    mb="2px"
                    fontSize="sm"
                    ms={{ base: "0px", md: "0px" }}
                    type={field.type}
                    fontWeight="500"
                    size="lg"
                    label={field.label}
                    extra="*"
                  />
                )
              )}
              <Button
                fontSize="sm"
                type="submit"
                variant="brand"
                fontWeight="500"
                w="100%"
                h="50"
                mb="24px"
                isLoading={loading}
                loadingText="Submitting..." 
                isDisabled={loading}>
          
                Submit
              </Button>
            </FormControl>
          </Form>
          <Flex
            flexDirection="column"
            justifyContent="center"
            alignItems="start"
            maxW="100%"
            mt="0px"
          >
            <Link href="/auth/signin">
              <Text color={textColorDetails} fontWeight="400" fontSize="14px">
                Already have an account?
                <Text
                  color={textColorBrand}
                  as="span"
                  ms="5px"
                  fontWeight="500"
                >
                  Login
                </Text>
              </Text>
            </Link>
          </Flex>
        </Flex>
      </Flex>
    </DefaultAuthLayout>
  );
}
